﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using System.Windows.Forms;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Configuration;

using Serilog;

namespace Catamaran
{
    internal static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);

            var services = new ServiceCollection();
            ConfigureServices(services);
            using (ServiceProvider serviceProvider = services.BuildServiceProvider())
            {
                Application.Run(serviceProvider.GetRequiredService<FormMapWithSetBoats>());
            }
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddSingleton<FormMapWithSetBoats>()
                .AddLogging(option =>
                {
                    var configuration = new ConfigurationBuilder().SetBasePath(Directory.GetCurrentDirectory()).AddJsonFile(path: "appsettings.json", optional: false, reloadOnChange: true).Build();
                    var logger = new LoggerConfiguration().ReadFrom.Configuration(configuration).CreateLogger();
                    option.SetMinimumLevel(LogLevel.Information);
                    option.AddSerilog(logger);
                });
        }
    }
}
